@@ -165,9 +165,6 @@ func (vhs *VHS) Setup() {
 	height := vhs.Options.Video.Style.Height - double(padding) - double(margin) - bar
 	vhs.Page = vhs.Page.MustSetViewport(width, height, 0, false)
 
-	// Let's wait until we can access the window.term variable.
-	vhs.Page = vhs.Page.MustWait("() => window.term != undefined")
-
 	// Find xterm.js canvases for the text and cursor layer for recording.
 	vhs.TextCanvas, _ = vhs.Page.Element("canvas.xterm-text-layer")
 	vhs.CursorCanvas, _ = vhs.Page.Element("canvas.xterm-cursor-layer")
@@ -352,7 +349,7 @@ func (vhs *VHS) Record(ctx context.Context) <-chan error {
 				if err := os.WriteFile(
 					filepath.Join(vhs.Options.Video.Input, fmt.Sprintf(cursorFrameFormat, counter)),
 					cursor,
-					os.ModePerm,
+					0o600,
 				); err != nil {
 					ch <- fmt.Errorf("error writing cursor frame: %w", err)
 					continue
@@ -360,7 +357,7 @@ func (vhs *VHS) Record(ctx context.Context) <-chan error {
 				if err := os.WriteFile(
 					filepath.Join(vhs.Options.Video.Input, fmt.Sprintf(textFrameFormat, counter)),
 					text,
-					os.ModePerm,
+					0o600,
 				); err != nil {
 					ch <- fmt.Errorf("error writing text frame: %w", err)
 					continue
